@@ -1,7 +1,7 @@
 package Module::FatPack;
 
 our $DATE = '2015-06-12'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -46,6 +46,7 @@ _
             pos => 0,
             greedy => 1,
             'x.schema.element_entity' => 'modulename',
+            cmdline_aliases => {m=>{}},
         },
         module_srcs => {
             summary => 'Module source codes',
@@ -56,6 +57,17 @@ _
             }],
             tags => ['category:input'],
         },
+        preamble => {
+            summary => 'Perl source code to add before the fatpack code',
+            schema => 'str*',
+            tags => ['category:input'],
+        },
+        postamble => {
+            summary => 'Perl source code to add after the fatpack code',
+            schema => 'str*',
+            tags => ['category:input'],
+        },
+
         output => {
             summary => 'Output filename',
             schema => 'str*',
@@ -186,6 +198,7 @@ sub fatpack_modules {
 
     my @res;
 
+    push @res, $args{preamble} if defined $args{preamble};
     push @res, 'BEGIN {', "\n";
     push @res, 'my %fatpacked;', "\n\n";
     for my $mod_pm (sort keys %module_srcs) {
@@ -235,6 +248,7 @@ else {
 unshift @INC, bless \%fatpacked, $class;
   } # END OF FATPACK CODE
 _
+    push @res, $args{postamble} if defined $args{postamble};
 
     if ($args{output}) {
         my $outfile = $args{output};
@@ -265,7 +279,7 @@ Module::FatPack - Generate source code that contains fatpacked modules
 
 =head1 VERSION
 
-This document describes version 0.03 of Module::FatPack (from Perl distribution Module-FatPack), released on 2015-06-12.
+This document describes version 0.04 of Module::FatPack (from Perl distribution Module-FatPack), released on 2015-06-12.
 
 =head1 SEE ALSO
 
@@ -308,6 +322,14 @@ Output filename.
 
 Whether to overwrite output if previously exists.
 
+=item * B<postamble> => I<str>
+
+Perl source code to add after the fatpack code.
+
+=item * B<preamble> => I<str>
+
+Perl source code to add before the fatpack code.
+
 =item * B<stripper> => I<bool> (default: 0)
 
 Whether to strip included modules using Perl::Stripper.
